/*  QNAME2.C
=========================================================================

    Original program -- QNAME.C

    QNAME.C -- renames ATBBS.QWK in current directory to new file name
    that contains current day and month.
    Written by Martin Leon, Ashton Tate Software Support using the
    Microsoft Quick C compiler.

=========================================================================

    QNAME.C modified to QNAME2.C
    by David J. Semon

    March 22, 1991

    Program modified to:

    1. Compile with Borland Turbo C 2.0 (struct date d) vs Microsoft
       Quick C (dosdate_t today).
    2. Allow any file name to be entered as a command line argument.
    3. Rename the input file to a new file name that contains the first
       three characters of the input file name plus current day, month
       and a sequence letter (A,B,C,D, etc.).

       Examples:     Assume DOS date = 03/22/91
                     Assume first file renamed on that date

                     ATBBS    becomes  ATB0322A.QWK
                     SEMWARE  becomes  SEM0322A.QWK
                     ABCDEFGH becomes  ABC0322A.QWK
                     AB       becomes  AB0322A.QWK
                     A        becomes  A0322A.QWK

    4. If no file name is provided, a message displays correct syntax.
    5. If the file name is not found, a message is displayed saying so.

======================================================================= */

#include <stdio.h>
#include <io.h>
#include <dos.h>
#include <string.h>
#include <process.h>

FILE *oldfile;
FILE *newfile;
struct date d;

char newname[13];
char oldname[13];
char prefix[4];
int x;

/*-------------------------------------------------------------------- */
int main(int argc, char *argv[])
  {
  if(argc < 2)                        /* No argument entered */
    {
    printf("Please enter a file name to rename ...\n");
    printf("Syntax: QNAME2 <filename>\n\n");
    exit(1);
    }
  else
    {
    strncat(oldname,argv[1],8);     /* Copy eight chars from argument  */
    if(strlen(oldname) > 3)         /* If name of file is greater than */
      {                             /*         three chars,            */
      strncat(prefix,oldname,3);  /* Copy first three characters */
      }
    else                            /*            else             */
      {
      strcpy(prefix,oldname);     /* Copy entire string */
      }
    strcat(oldname,".QWK");         /* Add .QWK extension to filename */
    strupr(oldname);                /* Convert name to upper case */
    strupr(prefix);                 /* Convert prefix to upper case */
    }

  /* Make sure file (oldname) exists */
  if((oldfile = fopen(oldname,"rt")) == NULL)
    {
    printf("%s not found in current directory ...\n\n",oldname);
    return 1;
    }
  else
    /* The file exists and is open. Close it */
   fclose(oldfile);

  /* Get today's date */
  getdate(&d);

  /* x = letter of the alphabet.  Start at "A", ASCII 65 */
  x = 65;

  /*  Use sprintf() to combine the month and day and the letter into
      a file name.  Check to see if it doesn't exist and rename. Do
      this until letter = "Z" */
  do
    {
    sprintf(newname, "%s%02u%02u%c.QWK", prefix, d.da_mon, d.da_day, x);

    if((newfile = fopen(newname,"rt")) == NULL)
      {
        /* File name doesn't exist, rename original to unused file name */
      if(rename(oldname,newname) != 0)
        {
        printf("Error renaming %s to %s\n\n",oldname,newname);
        return 1;
        }
      else
          /* If the rename was succesful, we're done with this loop */
       break;
      }
    else
      /* If the file existed, close it and go to next file name */
     fclose(newfile);
    }
  while (++x <= 90);

  /* If more than 26 files exist for today's date, give error message */
  if(x > 90)
    {
    printf("\nUnable to rename beyond %s%02u%02u%c.QWK\n",
     prefix, d.da_mon, d.da_day, x - 1 );
    return 1;
    }

  /* Rename completed */
  printf("%s renamed to %s\n\n",oldname,newname);
  return 0;
  }
